@@ -562,7 +562,7 @@ making the transformation <i>M_{in}</i> and then this transformation.
    
  
 <a name="anchor86"></a>
-<p/><strong> Vec4 RotBstMatrix::operator*(Vec4 p) const &nbsp;</strong> <br/>
+<p/><strong> Vec4 RotBstMatrix::operator*(Vec4 p) &nbsp;</strong> <br/>
 return a rotated and boosted version of <i>p</i>. 
    
  
@@ -573,7 +573,7 @@ of rotations and boosts.
    
  
 <a name="anchor88"></a>
-<p/><strong> RotBstMatrix RotBstMatrix::inverse() const &nbsp;</strong> <br/>
+<p/><strong> RotBstMatrix RotBstMatrix::inverse() &nbsp;</strong> <br/>
 return the inverse matrix, which corresponds to an opposite sequence and sign 
 of rotations and boosts, without overwriting the original matrix. 
    
@@ -649,4 +649,4 @@ when in the rest frame.
 </body>
 </html>
  
-<!-- Copyright (C) 2018 Torbjorn Sjostrand --> 
+<!-- Copyright (C) 2019 Torbjorn Sjostrand --> 
